@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -30,7 +30,7 @@ class BoolFalse(Object):
         return cls.value
 
     def __new__(cls) -> bytes:
-        return int.to_bytes(cls.ID, 4, "little")
+        return cls.ID.to_bytes(4, "little")
 
 
 class BoolTrue(BoolFalse):
