@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -16,12 +16,16 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+from typing import Iterable, Union, List
+
+import pyrogram
 from pyrogram.api import functions
-from ...ext import BaseClient, utils
+from ...ext import BaseClient
 
 
 class GetUsers(BaseClient):
-    def get_users(self, user_ids):
+    def get_users(self,
+                  user_ids: Iterable[Union[int, str]]) -> Union["pyrogram.User", List["pyrogram.User"]]:
         """Use this method to get information about a user.
         You can retrieve up to 200 users at once.
 
@@ -32,9 +36,9 @@ class GetUsers(BaseClient):
                 Iterators and Generators are also accepted.
 
         Returns:
-            On success and in case *user_ids* was a list, the returned value will be a list of the requested
+            On success and in case *user_ids* was an iterable, the returned value will be a list of the requested
             :obj:`Users <User>` even if a list contains just one element, otherwise if
-            *user_ids* was an integer, the single requested :obj:`User` is returned.
+            *user_ids* was an integer or string, the single requested :obj:`User` is returned.
 
         Raises:
             :class:`Error <pyrogram.Error>` in case of a Telegram RPC error.
@@ -52,6 +56,6 @@ class GetUsers(BaseClient):
         users = []
 
         for i in r:
-            users.append(utils.parse_user(i))
+            users.append(pyrogram.User._parse(self, i))
 
         return users if is_iterable else users[0]
