@@ -1,5 +1,5 @@
 # Pyrogram - Telegram MTProto API Client Library for Python
-# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
+# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
 #
 # This file is part of Pyrogram.
 #
@@ -26,11 +26,12 @@ from .location import Location
 from .message_entity import MessageEntity
 from ..messages_and_media.photo import Photo
 from ..pyrogram_type import PyrogramType
+from ..update import Update
 from ..user_and_chats.chat import Chat
 from ..user_and_chats.user import User
 
 
-class Message(PyrogramType):
+class Message(PyrogramType, Update):
     """This object represents a message.
 
     Args:
@@ -120,6 +121,9 @@ class Message(PyrogramType):
         animation (:obj:`Animation <pyrogram.Animation>`, *optional*):
             Message is an animation, information about the animation.
 
+        game (:obj:`Game <pyrogram.Game>`, *optional*):
+            Message is a game, information about the game.
+
         video (:obj:`Video <pyrogram.Video>`, *optional*):
             Message is a video, information about the video.
 
@@ -198,6 +202,10 @@ class Message(PyrogramType):
             Note that the Message object in this field will not contain further reply_to_message fields even if it
             is itself a reply.
 
+        game_high_score (:obj:`GameHighScore <pyrogram.GameHighScore>`, *optional*):
+            The game score for a user.
+            The reply_to_message field will contain the game Message.
+
         views (``int``, *optional*):
             Channel post views.
 
@@ -254,6 +262,7 @@ class Message(PyrogramType):
                  photo: "pyrogram.Photo" = None,
                  sticker: "pyrogram.Sticker" = None,
                  animation: "pyrogram.Animation" = None,
+                 game: "pyrogram.Game" = None,
                  video: "pyrogram.Video" = None,
                  voice: "pyrogram.Voice" = None,
                  video_note: "pyrogram.VideoNote" = None,
@@ -274,6 +283,7 @@ class Message(PyrogramType):
                  migrate_to_chat_id: int = None,
                  migrate_from_chat_id: int = None,
                  pinned_message: "Message" = None,
+                 game_high_score: int = None,
                  views: int = None,
                  via_bot: User = None,
                  outgoing: bool = None,
@@ -310,6 +320,7 @@ class Message(PyrogramType):
         self.photo = photo
         self.sticker = sticker
         self.animation = animation
+        self.game = game
         self.video = video
         self.voice = voice
         self.video_note = video_note
@@ -330,6 +341,7 @@ class Message(PyrogramType):
         self.migrate_to_chat_id = migrate_to_chat_id
         self.migrate_from_chat_id = migrate_from_chat_id
         self.pinned_message = pinned_message
+        self.game_high_score = game_high_score
         self.views = views
         self.via_bot = via_bot
         self.outgoing = outgoing
@@ -406,6 +418,19 @@ class Message(PyrogramType):
                 except MessageIdsEmpty:
                     pass
 
+            if isinstance(action, types.MessageActionGameScore):
+                parsed_message.game_high_score = pyrogram.GameHighScore._parse_action(client, message, users)
+
+                if message.reply_to_msg_id and replies:
+                    try:
+                        parsed_message.reply_to_message = client.get_messages(
+                            parsed_message.chat.id,
+                            reply_to_message_ids=message.id,
+                            replies=0
+                        )
+                    except MessageIdsEmpty:
+                        pass
+
             return parsed_message
 
         if isinstance(message, types.Message):
@@ -434,6 +459,7 @@ class Message(PyrogramType):
             location = None
             contact = None
             venue = None
+            game = None
             audio = None
             voice = None
             animation = None
@@ -455,6 +481,8 @@ class Message(PyrogramType):
                     contact = Contact._parse(client, media)
                 elif isinstance(media, types.MessageMediaVenue):
                     venue = pyrogram.Venue._parse(client, media)
+                elif isinstance(media, types.MessageMediaGame):
+                    game = pyrogram.Game._parse(client, message)
                 elif isinstance(media, types.MessageMediaDocument):
                     doc = media.document
 
@@ -542,6 +570,7 @@ class Message(PyrogramType):
                 audio=audio,
                 voice=voice,
                 animation=animation,
+                game=game,
                 video=video,
                 video_note=video_note,
                 sticker=sticker,
@@ -883,7 +912,7 @@ class Message(PyrogramType):
         else:
             raise ValueError("The message doesn't contain any keyboard")
 
-    def download(self, file_name: str = "", block: bool = True, progress: callable = None, progress_args: tuple = None):
+    def download(self, file_name: str = "", block: bool = True, progress: callable = None, progress_args: tuple = ()):
         """Bound method *download* of :obj:`Message <pyrogram.Message>`.
 
         Use as a shortcut for:
